import { ViewModel, Vue } from './types';
import { sendErrorToNoibu } from './core';

// lazy definiton of the errorHandler function
type UnknownFunc = (...args: unknown[]) => void;
/**
 * Attaches an error listener to the vue app, calling all previous handlers as well
 * @param  {Vue} app
 */
export const attachErrorHandler = (app: Vue) => {
  const { errorHandler } = app.config;

  // we need to reassign the param to override the listener
  // eslint-disable-next-line no-param-reassign
  app.config.errorHandler = (
    error: Error,
    vm: ViewModel,
    lifecycleHook: string,
  ): void => {
    sendErrorToNoibu(error);
    if (typeof errorHandler === 'function') {
      (errorHandler as UnknownFunc).call(app, error, vm, lifecycleHook);
    }
  };
};
